// This file is autogenerated by hidl-gen. Do not edit manually.
// Source: android.hardware.nfc@1.0
// Root: android.hardware:hardware/interfaces

#ifndef HIDL_GENERATED_ANDROID_HARDWARE_NFC_V1_0_EXPORTED_CONSTANTS_H_
#define HIDL_GENERATED_ANDROID_HARDWARE_NFC_V1_0_EXPORTED_CONSTANTS_H_

#ifdef __cplusplus
extern "C" {
#endif

enum {
    HAL_NFC_OPEN_CPLT_EVT = 0u, // 0
    HAL_NFC_CLOSE_CPLT_EVT = 1u, // 1
    HAL_NFC_POST_INIT_CPLT_EVT = 2u, // 2
    HAL_NFC_PRE_DISCOVER_CPLT_EVT = 3u, // 3
    HAL_NFC_REQUEST_CONTROL_EVT = 4u, // 4
    HAL_NFC_RELEASE_CONTROL_EVT = 5u, // 5
    HAL_NFC_ERROR_EVT = 6u, // 6
};

enum {
    HAL_NFC_STATUS_OK = 0u, // 0
    HAL_NFC_STATUS_FAILED = 1u, // 1
    HAL_NFC_STATUS_ERR_TRANSPORT = 2u, // 2
    HAL_NFC_STATUS_ERR_CMD_TIMEOUT = 3u, // 3
    HAL_NFC_STATUS_REFUSED = 4u, // 4
};

#ifdef __cplusplus
}
#endif

#endif  // HIDL_GENERATED_ANDROID_HARDWARE_NFC_V1_0_EXPORTED_CONSTANTS_H_
